StrawHat.Map v1.0.0 StrawHat.Map.Location View Source
Represents a Location Ecto Schema with functionality about the data validation for Location.
Link to this section Summary
Types
Check t/0 type for more information about the keys
location: theGeo.Point.t/0of the location of the Location.address:StrawHat.Map.Address.t/0associated with the location.address_id:idofStrawHat.Map.Address.t/0associated with the location
Functions
Validates the attributes and return a Ecto.Changeset for the current Location
Link to this section Types
Check t/0 type for more information about the keys.
location: the GeoJSON Point structure for the location of the Location.
Link to this type
t()
t() :: %StrawHat.Map.Location{
__meta__: term(),
address: StrawHat.Map.Address.t() | Ecto.Association.NotLoaded.t(),
address_id: String.t(),
id: term(),
location: Geo.Point.t()
}
location: theGeo.Point.t/0of the location of the Location.address:StrawHat.Map.Address.t/0associated with the location.address_id:idofStrawHat.Map.Address.t/0associated with the location.
Link to this section Functions
Link to this function
changeset(location, location_attrs)
changeset(t(), location_attrs()) :: Ecto.Changeset.t()
Validates the attributes and return a Ecto.Changeset for the current Location.